==> bfom-lib-0.1.37.crate: bfom-lib-0.1.37/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v0.1.37 (2022-01-27)

### Bug Fixes

 - <csr-id-dbc2ffbbc6763926fd68ec94a0e8017f39e337bc/> for bumping the package
 - <csr-id-7972d63dec99cf5b3ea5b7f268b91e680483d998/> for bumping the package
 - <csr-id-73c430c5aab75e36d7c9d84343e0e9b45c5ee6f7/> for bumping the package for testing

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 1 commit contributed to the release.
 - 1 commit where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - for bumping the package for testing (73c430c)
</details>

## v0.1.36 (2022-01-22)

### New Features

 - <csr-id-76709b54674db955e30f809fb3653bffd1984d36/> split up the general conversion and my own blog, will allow me to customise the blog as much as I like

### Bug Fixes

 - <csr-id-4a96393f56f8989c0d4a9a9b193177f2929ac523/> switching to 2021 seems to be fine

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 6 commits contributed to the release.
 - 3 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Bump bfom-lib v0.1.36, bfom v0.1.35, bfom-blog v0.1.0 (efc92c2)
    - improved the formatting (cd87337)
    - switching to 2021 seems to be fine (4a96393)
    - split up the general conversion and my own blog, will allow me to customise the blog as much as I like (76709b5)
    - fmt (bfba0c4)
    - Merge branch 'general_improvements' (9e0c312)
</details>

## v0.1.35 (2021-09-19)

### New Features

 - <csr-id-fbaab53960f76929fb584d2628d72e5e9fe26299/> added some basic tests
 - <csr-id-7b27b91a5732a1af1768876db64069970991f1b9/> split line_data into its own module
 - <csr-id-8a3e0015f95abc21e7419391b23c6a590bcfc134/> successfully changed linetype to being an enum.
   Overall this does make it far neater and intuitive.
 - <csr-id-651dd2385359c917e63a051273a31a92d1b26f09/> lists now work on teh new line type function/enum
 - <csr-id-5bd5161ad0b6e359aa8d441299dc2b140e08fe0e/> better fmt options
 - <csr-id-bc216171cde11b8c0f024cff43d583e69ac8418f/> first step into using enums

### Bug Fixes

 - <csr-id-c7543a49ba144edab909572e31f83a208017a72e/> removed unused varible
 - <csr-id-da426ba981a03c03ebbbbce1d8c73049bd5f7f59/> no longer using cargo release, now using cargo smart-release as it can handle modules with different versions easier

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 9 commits contributed to the release over the course of 23 calendar days.
 - 8 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release bfom-lib v0.1.35 (01acb87)
    - added some basic tests (fbaab53)
    - removed unused varible (c7543a4)
    - split line_data into its own module (7b27b91)
    - successfully changed linetype to being an enum. (8a3e001)
    - lists now work on teh new line type function/enum (651dd23)
    - better fmt options (5bd5161)
    - first step into using enums (bc21617)
    - no longer using cargo release, now using cargo smart-release as it can handle modules with different versions easier (da426ba)
</details>

## v0.1.34 (2021-08-27)

### New Features

 - <csr-id-3e4a4df6686e4874a3999d1bc152ca7e705b6949/> split out the converter even further
 - <csr-id-ab42a61597fcdb78a2293e86d261d00691a4ce76/> split out the converter

### Bug Fixes

 - <csr-id-78bf37f3d82b912b55dca315e6160d46780a312d/> a clean starting point for testing to resume on
 - <csr-id-ccd3b5090c4624c6aecc2e6269bf57b1a8b80bb9/> properly handle < and > in inline code blocks
 - <csr-id-c6ac74b58d8ebeb78971d520b213a0b29ce6024d/> only do one tag

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 13 commits contributed to the release over the course of 19 calendar days.
 - 6 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release bfom-lib v0.1.34 (9e04fe9)
    - releasing updated lib (6e557b0)
    - test; bump to 33 for more testing of cargo workspaces (d9d16c2)
    - a clean starting point for testing to resume on (78bf37f)
    - test:  bumping both subprojects (f1624e1)
    - v0.1.28 (c369692)
    - properly handle < and > in inline code blocks (ccd3b50)
    - v0.1.27 (7ca6809)
    - split out the converter even further (3e4a4df)
    - split out the converter (ab42a61)
    - v0.1.26 (d7cf1de)
    - v0.1.25 (dfbaf00)
    - only do one tag (c6ac74b)
</details>

## v0.1.24 (2021-08-07)

### New Features

 - <csr-id-7a4c8d9bc9f23d2c1fb7d3ade29196accca82e3c/> centralising the use of cargo release
 - <csr-id-1a78feea1f27784ed9787b0cde4e707fcf2c317b/> split out the project into a lib and binary, each having their own dependencies

### Bug Fixes

 - <csr-id-6105645b5c516c80e60172c322acf66e4f142f00/> make sure each sub project has its own license files

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 7 commits contributed to the release.
 - 5 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - v0.1.24 (0e4f731)
    - v0.1.23 (b4e9c92)
    - centralising the use of cargo release (7a4c8d9)
    - updated result (f24a63b)
    - updated all the readme's (dae8f92)
    - make sure each sub project has its own license files (6105645)
    - split out the project into a lib and binary, each having their own dependencies (1a78fee)
</details>

==> bfom-lib-0.1.38.crate: bfom-lib-0.1.38/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v0.1.38 (2022-01-27)

### Bug Fixes

 - <csr-id-492b7baae4c381636904a85bd1bf74589222187e/> fixing some formatting

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 1 commit contributed to the release.
 - 1 commit where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - fixing some formatting (492b7ba)
</details>

## v0.1.37 (2022-01-27)

### Bug Fixes

 - <csr-id-dbc2ffbbc6763926fd68ec94a0e8017f39e337bc/> for bumping the package
 - <csr-id-7972d63dec99cf5b3ea5b7f268b91e680483d998/> for bumping the package
 - <csr-id-73c430c5aab75e36d7c9d84343e0e9b45c5ee6f7/> for bumping the package for testing

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 8 commits contributed to the release over the course of 5 calendar days.
 - 4 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Bump bfom-lib v0.1.37, bfom v0.1.36, bfom-blog v0.1.2 (eaf2e2a)
    - for bumping the package for testing (73c430c)
    - Bump bfom-lib v0.1.37, bfom v0.1.36, bfom-blog v0.1.2 (b92d078)
    - for bumping the package (7972d63)
    - Bump bfom-lib v0.1.37, bfom v0.1.36, bfom-blog v0.1.2 (dade144)
    - for bumping the package (dbc2ffb)
    - Bump bfom-lib v0.1.37, bfom v0.1.36, bfom-blog v0.1.1 (4a70751)
    - going to ttry out teh docs from the tool (71e3a84)
</details>

## v0.1.36 (2022-01-22)

### New Features

 - <csr-id-76709b54674db955e30f809fb3653bffd1984d36/> split up the general conversion and my own blog, will allow me to customise the blog as much as I like

### Bug Fixes

 - <csr-id-4a96393f56f8989c0d4a9a9b193177f2929ac523/> switching to 2021 seems to be fine

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 6 commits contributed to the release.
 - 3 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Bump bfom-lib v0.1.36, bfom v0.1.35, bfom-blog v0.1.0 (efc92c2)
    - improved the formatting (cd87337)
    - switching to 2021 seems to be fine (4a96393)
    - split up the general conversion and my own blog, will allow me to customise the blog as much as I like (76709b5)
    - fmt (bfba0c4)
    - Merge branch 'general_improvements' (9e0c312)
</details>

## v0.1.35 (2021-09-19)

### New Features

 - <csr-id-fbaab53960f76929fb584d2628d72e5e9fe26299/> added some basic tests
 - <csr-id-7b27b91a5732a1af1768876db64069970991f1b9/> split line_data into its own module
 - <csr-id-8a3e0015f95abc21e7419391b23c6a590bcfc134/> successfully changed linetype to being an enum.
   Overall this does make it far neater and intuitive.
 - <csr-id-651dd2385359c917e63a051273a31a92d1b26f09/> lists now work on teh new line type function/enum
 - <csr-id-5bd5161ad0b6e359aa8d441299dc2b140e08fe0e/> better fmt options
 - <csr-id-bc216171cde11b8c0f024cff43d583e69ac8418f/> first step into using enums

### Bug Fixes

 - <csr-id-c7543a49ba144edab909572e31f83a208017a72e/> removed unused varible
 - <csr-id-da426ba981a03c03ebbbbce1d8c73049bd5f7f59/> no longer using cargo release, now using cargo smart-release as it can handle modules with different versions easier

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 9 commits contributed to the release over the course of 23 calendar days.
 - 8 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release bfom-lib v0.1.35 (01acb87)
    - added some basic tests (fbaab53)
    - removed unused varible (c7543a4)
    - split line_data into its own module (7b27b91)
    - successfully changed linetype to being an enum. (8a3e001)
    - lists now work on teh new line type function/enum (651dd23)
    - better fmt options (5bd5161)
    - first step into using enums (bc21617)
    - no longer using cargo release, now using cargo smart-release as it can handle modules with different versions easier (da426ba)
</details>

## v0.1.34 (2021-08-27)

### New Features

 - <csr-id-3e4a4df6686e4874a3999d1bc152ca7e705b6949/> split out the converter even further
 - <csr-id-ab42a61597fcdb78a2293e86d261d00691a4ce76/> split out the converter

### Bug Fixes

 - <csr-id-78bf37f3d82b912b55dca315e6160d46780a312d/> a clean starting point for testing to resume on
 - <csr-id-ccd3b5090c4624c6aecc2e6269bf57b1a8b80bb9/> properly handle < and > in inline code blocks
 - <csr-id-c6ac74b58d8ebeb78971d520b213a0b29ce6024d/> only do one tag

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 13 commits contributed to the release over the course of 19 calendar days.
 - 6 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - Release bfom-lib v0.1.34 (9e04fe9)
    - releasing updated lib (6e557b0)
    - test; bump to 33 for more testing of cargo workspaces (d9d16c2)
    - a clean starting point for testing to resume on (78bf37f)
    - test:  bumping both subprojects (f1624e1)
    - v0.1.28 (c369692)
    - properly handle < and > in inline code blocks (ccd3b50)
    - v0.1.27 (7ca6809)
    - split out the converter even further (3e4a4df)
    - split out the converter (ab42a61)
    - v0.1.26 (d7cf1de)
    - v0.1.25 (dfbaf00)
    - only do one tag (c6ac74b)
</details>

## v0.1.24 (2021-08-07)

### New Features

 - <csr-id-7a4c8d9bc9f23d2c1fb7d3ade29196accca82e3c/> centralising the use of cargo release
 - <csr-id-1a78feea1f27784ed9787b0cde4e707fcf2c317b/> split out the project into a lib and binary, each having their own dependencies

### Bug Fixes

 - <csr-id-6105645b5c516c80e60172c322acf66e4f142f00/> make sure each sub project has its own license files

### Commit Statistics

<csr-read-only-do-not-edit/>

 - 7 commits contributed to the release.
 - 5 commits where understood as [conventional](https://www.conventionalcommits.org).
 - 0 issues like '(#ID)' where seen in commit messages

### Commit Details

<csr-read-only-do-not-edit/>

<details><summary>view details</summary>

 * **Uncategorized**
    - v0.1.24 (0e4f731)
    - v0.1.23 (b4e9c92)
    - centralising the use of cargo release (7a4c8d9)
    - updated result (f24a63b)
    - updated all the readme's (dae8f92)
    - make sure each sub project has its own license files (6105645)
    - split out the project into a lib and binary, each having their own dependencies (1a78fee)
</details>
